@@ -84,6 +84,8 @@ extern "C"
 
 int kdemain(int argc, char **argv)
 {
+    QCoreApplication app(argc, argv);
+
     QCoreApplication::setApplicationName("kio_kamera");
     KLocalizedString::setApplicationDomain("kio_kamera");
 
@@ -496,6 +498,24 @@ void KameraProtocol::statRegular(const QUrl &xurl)
     if (directory == "/") {
         KIO::UDSEntry entry;
 
+#define GPHOTO_TEXT_FILE(xx) \
+        if (!file.compare(#xx".txt")) { \
+            CameraText xx; \
+            gpr = gp_camera_get_about(m_camera,  &xx, m_context); \
+            if (gpr != GP_OK) { \
+                error(KIO::ERR_DOES_NOT_EXIST, xurl.fileName()); \
+                return; \
+            } \
+            translateTextToUDS(entry,#xx".txt",xx.text); \
+            statEntry(entry); \
+            finished(); \
+            return; \
+        }
+        GPHOTO_TEXT_FILE(about);
+        GPHOTO_TEXT_FILE(manual);
+        GPHOTO_TEXT_FILE(summary);
+#undef GPHOTO_TEXT_FILE
+
         QString xname = current_camera + "@" + current_port;
         entry.insert( KIO::UDSEntry::UDS_NAME, path_quote(xname));
         entry.insert( KIO::UDSEntry::UDS_DISPLAY_NAME, current_camera);
@@ -528,24 +548,6 @@ void KameraProtocol::statRegular(const QUrl &xurl)
         return;
     }
 
-#define GPHOTO_TEXT_FILE(xx) \
-    if (!directory.compare("/") && !file.compare(#xx".txt")) { \
-        CameraText xx; \
-        gpr = gp_camera_get_about(m_camera,  &xx, m_context); \
-        if (gpr != GP_OK) { \
-            error(KIO::ERR_DOES_NOT_EXIST, xurl.fileName()); \
-            return; \
-        } \
-        translateTextToUDS(entry,#xx".txt",xx.text); \
-        statEntry(entry); \
-        finished(); \
-        return; \
-    }
-    GPHOTO_TEXT_FILE(about);
-    GPHOTO_TEXT_FILE(manual);
-    GPHOTO_TEXT_FILE(summary);
-#undef GPHOTO_TEXT_FILE
-
     const char *name;
     for(int i = 0; i < gp_list_count(dirList); i++) {
         gp_list_get_name(dirList, i, &name);
@@ -970,6 +972,7 @@ void KameraProtocol::translateTextToUDS(KIO::UDSEntry &udsEntry,
     udsEntry.insert(KIO::UDSEntry::UDS_DISPLAY_NAME,fn);
     udsEntry.insert(KIO::UDSEntry::UDS_SIZE,strlen(text));
     udsEntry.insert(KIO::UDSEntry::UDS_ACCESS,(S_IRUSR | S_IRGRP | S_IROTH));
+    udsEntry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QString("text/plain"));
 }
 
 // translate a CameraFileInfo to a UDSFieldType
